@@ -8,6 +8,7 @@
 #
 import time
 import json
+import types 
 import random
 
 import pymongo
@@ -18,43 +19,23 @@ from bson import json_util
 
 class Model():
     def __init__(self,**arg):
-        class_l   = [val for val in dir(self) if val not in dir(Model)] #减法，去掉model 和self的相同，留下model的Property()值
-        if 'BOXURL' in class_l:
-            class_l.remove('BOXURL')
+        class_dict_more = self.__class__.__dict__.copy()
+        self.pymongo_connection = class_dict_more['BOXURL'] if class_dict_more.has_key('BOXURL') else "mongodb://127.0.0.1:27017" #self.pymongo_connection
 
-        class_list = []
-        for i in class_l:
-            if i[0:11] =='boxmongodb_':
-                pass
-            else:
-                class_list.append(i)
+        for i in class_dict_more.items():
+            a = None if type(i[1]) is types.ListType else class_dict_more.pop(i[0])
 
-        class_dict_more = self.__class__.__dict__  #直接在 Property 的返回列表 [me,property_dict,default,{}]
+        self.datetime_property = [] #self.datetime_property 
+        for i in class_dict_more.items():
+            if  i[1][0]  == 'datetime_property' and i[1][1]['auto_now']:self.datetime_property.append((i[0],class_dict_more[i[0]]))
 
-        if class_dict_more.has_key('BOXURL'):
-            pymongo_connection = class_dict_more['BOXURL']
-        else:
-            pymongo_connection = "mongodb://127.0.0.1:27017"
+        arg_1 = arg.copy()
+        for i in class_dict_more.items():
+            arg_1[i[0]] = ModelFilter(arg[i[0]],i[1]) if arg_1.has_key(i[0]) else i[1][2]
 
-        self.datetime_property = []
+        self.value = arg_1 #self.value
 
-        class_dict      = {}
-        for li in class_list:
-            class_dict[li] = class_dict_more[li] #这个是完整的字典
 
-            if class_dict_more[li][0] == 'datetime_property':
-                if class_dict_more[li][1]['auto_now']:
-                    self.datetime_property.append((li,class_dict_more[li])) #添加 datetime_property 的功能
-
-        arg_1 = arg
-        for class_dict_items in class_dict.items():
-            arg_1_has_key = arg_1.has_key(class_dict_items[0])
-            if arg_1_has_key:
-                arg_1[class_dict_items[0]] = ModelFilter(arg[class_dict_items[0]],class_dict_items[1])#这里对输入值进行过滤
-            else:
-                arg_1[class_dict_items[0]] = class_dict_items[1][2] #,返回model里面的默认值#首先是外属性0，然后是内属性1，再是默认值2，再是附加值3
-        self.pymongo_connection = pymongo_connection
-        self.value = arg_1#这个是重点
 
     @property
     def mongodb_db(self):
@@ -79,7 +60,7 @@ class Model():
         self.conn = pymongo.MongoClient(self.pymongo_connection)
         self.db_name = self.conn[db]
         self.db_name_table_name = self.db_name[table]
-        data = self.db_name_table_name.insert(self.value) #奇怪的现象是 self.value 被改变了，会被添加ObjectId
+        data = self.db_name_table_name.insert(self.value) 
         
         return self.value
 
@@ -105,8 +86,6 @@ class Model():
         return dic
 
 
-#删除记录 (不带条件表示全部删除)
-#account.remove({"name": "mike"})
     @classmethod
     def remove(cls,name,value):#自己的num或者key
         all_name = cls.__name__
@@ -250,7 +229,11 @@ class Model():
         else:
             for i in self.datetime_property:
                     new_value[i[0]] = data_old[0][i[0]]
-
+        
+        print 'new_value'
+        print new_value
+        print 'new_value'
+        
         data = self.db_name_table_name.update({name:value},{"$set":new_value})
         return data#返回ture 布尔值
 
@@ -275,6 +258,10 @@ class Model():
             for i in self.datetime_property:
                     new_value[i[0]] = data_old[i[0]]
 
+        print 'new_value'
+        print new_value
+        print 'new_value'
+
         data = self.db_name_table_name.update({"_id":ObjectId(value)},{"$set":new_value})
         return data#返回ture 布尔值
 
@@ -395,6 +382,3 @@ class EmailProperty(object):
         return [me,email_property_dict,default,{}]
 
 
-
-def sayHello():
-    print 'Hello World!'
